@@ -628,6 +628,12 @@ class BackendCalDAV extends BackendDiff {
                     }
                     break;
 
+                case "X-MICROSOFT-CDO-ALLDAYEVENT":
+                    if ($property->Value() == "TRUE") {
+                        $message->alldayevent = "1";
+                    }
+                    break;
+
                 case "DURATION":
                     if (!isset($message->endtime)) {
                         $start = date_create("@" . $message->starttime);
@@ -656,13 +662,35 @@ class BackendCalDAV extends BackendDiff {
                     break;
 
                 case "TRANSP":
+                    if(!isset($message->busystatus)){
+                        switch ($property->Value()) {
+                            case "TRANSPARENT":
+                                $message->busystatus = "0";
+                                break;
+                            case "OPAQUE":
+                                $message->busystatus = "2";
+                                break;
+                        }
+                    }
+                    break;
+
+                case "X-MICROSOFT-CDO-INTENDEDSTATUS":
                     switch ($property->Value()) {
-                        case "TRANSPARENT":
+                        case "FREE":
                             $message->busystatus = "0";
                             break;
-                        case "OPAQUE":
+                        case "TENTATIVE":
+                            $message->busystatus = "1";
+                            break;
+                        case "BUSY":
                             $message->busystatus = "2";
                             break;
+                        case "OOF":
+                            $message->busystatus = "3";
+                            break;
+                        case "WORKINGELSEWHERE":
+                            $message->busystatus = "4";
+                            break;
                     }
                     break;
 
@@ -769,10 +797,18 @@ class BackendCalDAV extends BackendDiff {
             }
         }
 
-        // Workaround #127 - No organizeremail defined
-        if (!isset($message->organizeremail)) {
-            ZLog::Write(LOGLEVEL_DEBUG, sprintf("BackendCalDAV->_ParseVEventToSyncObject(): No organizeremail defined, using username"));
-            $message->organizeremail = $this->originalUsername;
+        if ($message->meetingstatus > 0) {
+            // No organizer was set for the meeting, assume it is the user
+            if (!isset($message->organizeremail)) {
+                ZLog::Write(LOGLEVEL_DEBUG, sprintf("BackendCalDAV->_ParseVEventToSyncObject(): No organizeremail defined, using user details"));
+                $userDetails = ZPush::GetBackend()->GetCurrentUsername();
+                $message->organizeremail = $userDetails['emailaddress'];
+                $message->organizername = $userDetails['fullname'];
+            }
+            // Ensure the organizer name is set
+            if (!isset($message->organizername)) {
+                $message->organizername = Utils::GetLocalPartFromEmail($message->organizeremail);
+            }
         }
 
         $valarm = current($event->GetComponents("VALARM"));
@@ -982,14 +1018,6 @@ class BackendCalDAV extends BackendDiff {
         if (isset($data->subject)) {
             $vevent->AddProperty("SUMMARY", $data->subject);
         }
-        if (isset($data->organizeremail)) {
-            if (isset($data->organizername)) {
-                $vevent->AddProperty("ORGANIZER", sprintf("MAILTO:%s", $data->organizeremail), array("CN" => $data->organizername));
-            }
-            else {
-                $vevent->AddProperty("ORGANIZER", sprintf("MAILTO:%s", $data->organizeremail));
-            }
-        }
         if (isset($data->location)) {
             $vevent->AddProperty("LOCATION", $data->location);
         }
@@ -1003,6 +1031,9 @@ class BackendCalDAV extends BackendDiff {
                 $vevent->AddProperty("X-MICROSOFT-CDO-ALLDAYEVENT", "FALSE");
             }
         }
+        else {
+            $vevent->AddProperty("X-MICROSOFT-CDO-ALLDAYEVENT", "TRUE");
+        }
         if (isset($data->recurrence)) {
             $vevent->AddProperty("RRULE", $this->_GenerateRecurrence($data->recurrence));
         }
@@ -1021,13 +1052,25 @@ class BackendCalDAV extends BackendDiff {
         }
         if (isset($data->busystatus)) {
             switch ($data->busystatus) {
-                case "0":
-                case "1":
+                case "0": //Free
                     $vevent->AddProperty("TRANSP", "TRANSPARENT");
+                    $vevent->AddProperty("X-MICROSOFT-CDO-INTENDEDSTATUS", "FREE");
                     break;
-                case "2":
-                case "3":
+                case "1": //Tentative
                     $vevent->AddProperty("TRANSP", "OPAQUE");
+                    $vevent->AddProperty("X-MICROSOFT-CDO-INTENDEDSTATUS", "TENTATIVE");
+                    break;
+                case "2": //Busy
+                    $vevent->AddProperty("TRANSP", "OPAQUE");
+                    $vevent->AddProperty("X-MICROSOFT-CDO-INTENDEDSTATUS", "BUSY");
+                    break;
+                case "3": //Out of office
+                    $vevent->AddProperty("TRANSP", "TRANSPARENT");
+                    $vevent->AddProperty("X-MICROSOFT-CDO-INTENDEDSTATUS", "OOF");
+                    break;
+                case "4": //Working elsewhere (not yet in Android)
+                    $vevent->AddProperty("TRANSP", "TRANSPARENT");
+                    $vevent->AddProperty("X-MICROSOFT-CDO-INTENDEDSTATUS", "WORKINGELSEWHERE");
                     break;
             }
         }
@@ -1046,7 +1089,7 @@ class BackendCalDAV extends BackendDiff {
             $rtfparser->parse();
             $vevent->AddProperty("DESCRIPTION", $rtfparser->out);
         }
-        if (isset($data->meetingstatus)) {
+        if (isset($data->meetingstatus) && $data->meetingstatus > 0) {
             switch ($data->meetingstatus) {
                 case "1":
                     $vevent->AddProperty("STATUS", "TENTATIVE");
@@ -1065,28 +1108,36 @@ class BackendCalDAV extends BackendDiff {
                     $vevent->AddProperty("X-MICROSOFT-DISALLOW-COUNTER", "TRUE");
                     break;
             }
-        }
-        if (isset($data->attendees) && is_array($data->attendees)) {
-            //If there are attendees, we need to set ORGANIZER
-            //Some phones doesn't send the organizeremail, so we gotto get it somewhere else.
-            //Lets use the login here ($username)
-            if (!isset($data->organizeremail)) {
-                $vevent->AddProperty("ORGANIZER", sprintf("MAILTO:%s", $this->originalUsername));
+            if (isset($data->organizeremail) && isset($data->organizername)) {
+                $vevent->AddProperty("ORGANIZER", sprintf("MAILTO:%s", $data->organizeremail), array("CN" => $data->organizername));
             }
-            foreach ($data->attendees as $att) {
-                if (isset($att->name)) {
-                    $vevent->AddProperty("ATTENDEE", sprintf("MAILTO:%s", $att->email), array("CN" => $att->name));
-                }
-                else {
-                    $vevent->AddProperty("ATTENDEE", sprintf("MAILTO:%s", $att->email));
+            elseif (isset($data->organizeremail)) {
+                $vevent->AddProperty("ORGANIZER", sprintf("MAILTO:%s", $data->organizeremail));
+            }
+            else {
+                //Some phones doesn't send the organizeremail, so we gotto get it somewhere else.
+                $userDetails = ZPush::GetBackend()->GetCurrentUsername();
+                $vevent->AddProperty("ORGANIZER", sprintf("MAILTO:%s", $userDetails['emailaddress']), array("CN" => $userDetails['fullname']));
+            }
+            if (isset($data->attendees) && is_array($data->attendees)) {
+                foreach ($data->attendees as $att) {
+                    if (isset($att->name)) {
+                        $vevent->AddProperty("ATTENDEE", sprintf("MAILTO:%s", $att->email), array("CN" => $att->name));
+                    }
+                    else {
+                        $vevent->AddProperty("ATTENDEE", sprintf("MAILTO:%s", $att->email));
+                    }
                 }
             }
         }
-        if (isset($data->body)) {
+        if (isset($data->body) && strlen($data->body) > 0) {
             $vevent->AddProperty("DESCRIPTION", $data->body);
         }
         if (isset($data->asbody->data)) {
-            $vevent->AddProperty("DESCRIPTION", stream_get_contents($data->asbody->data));
+            $asbody = stream_get_contents($data->asbody->data);
+            if (strlen($asbody) > 0) {
+                $vevent->AddProperty("DESCRIPTION", $asbody);
+            }
         }
         if (isset($data->categories) && is_array($data->categories)) {
             $vevent->AddProperty("CATEGORIES", implode(",", $data->categories));
@@ -1094,7 +1145,6 @@ class BackendCalDAV extends BackendDiff {
 
 // X-MICROSOFT-CDO-APPT-SEQUENCE:0
 // X-MICROSOFT-CDO-OWNERAPPTID:2113393086
-// X-MICROSOFT-CDO-INTENDEDSTATUS:BUSY
 // X-MICROSOFT-CDO-IMPORTANCE:1
 // X-MICROSOFT-CDO-INSTTYPE:0
 
