@@ -202,17 +202,17 @@ class Kopano extends ContactWorker {
                 continue;
             }
             // ignore ROOMS
-            elseif (isset($entry[PR_DISPLAY_TYPE_EX]) && $entry[PR_DISPLAY_TYPE_EX] & DT_ROOM) {
+            elseif (isset($entry[PR_DISPLAY_TYPE_EX]) && $entry[PR_DISPLAY_TYPE_EX] == DT_ROOM) {
                 $ignored++;
                 continue;
             }
             // ignore EQUIPMENT
-            elseif (isset($entry[PR_DISPLAY_TYPE_EX]) && $entry[PR_DISPLAY_TYPE_EX] & DT_EQUIPMENT) {
+            elseif (isset($entry[PR_DISPLAY_TYPE_EX]) && $entry[PR_DISPLAY_TYPE_EX] == DT_EQUIPMENT) {
                 $ignored++;
                 continue;
             }
             // ignore ORGANIZATION
-            elseif (isset($entry[PR_DISPLAY_TYPE_EX]) && $entry[PR_DISPLAY_TYPE_EX] & DT_ORGANIZATION) {
+            elseif (isset($entry[PR_DISPLAY_TYPE_EX]) && $entry[PR_DISPLAY_TYPE_EX] == DT_ORGANIZATION) {
                 $ignored++;
                 continue;
             }
@@ -262,7 +262,7 @@ class Kopano extends ContactWorker {
             // save the hash in the message as well
             mapi_setprops($mapimessage, array($this->mapiprops['hash'] => $contact->GetHash()));
             $mapiprovider->SetMessage($mapimessage, $contact);
-            mapi_message_savechanges($mapimessage);
+            mapi_savechanges($mapimessage);
             unset($existingByAccount[$contact->accountname]);
         }
 
